@@ -8,7 +8,7 @@ DEFAULT_SAMPLE_RATE = 1e6
 DEFAULT_BANDWIDTH = 1e6
 DEFAULT_GAIN = 20
 DEFAULT_IF_GAIN = 20
-DEFAULT_BB_GAIN = 20
+DEFAULT_BB_GAIN = 16
 DEFAULT_FREQ_CORRECTION = 1
 DEFAULT_DIRECT_SAMPLING_MODE = 0
 
@@ -20,10 +20,18 @@ K = 10 ** 3
 M = 10 ** 6
 G = 10 ** 9
 
+DEVICE_CONFIG["PlutoSDR"] = {
+    "center_freq": dev_range(start=70 * M, stop=6 * G, step=1),
+    "sample_rate": dev_range(start=2.1 * M, stop=61.44 * M, step=1),
+    "bandwidth": dev_range(start=0.2 * M, stop=56 * M, step=1),
+    "tx_rf_gain": list(range(-89, 1)),
+    "rx_rf_gain": list(range(-3, 72)),
+}
+
 # http://www.nuand.com/bladeRF-brief.pdf
 DEVICE_CONFIG["BladeRF"] = {
     "center_freq": dev_range(start=300 * M, stop=3.8 * G, step=1),
-    "sample_rate": dev_range(start=1.5 * M, stop=40 * M, step=1),
+    "sample_rate": dev_range(start=2.5 * M, stop=40 * M, step=1),
     "bandwidth": dev_range(start=1.5 * M, stop=28 * M, step=1),
     "rx_channel": ["RX1", "RX2"],
     "tx_channel": ["TX1", "TX2"],
@@ -48,9 +56,11 @@ DEVICE_CONFIG["USRP"] = {
     "center_freq": dev_range(start=0, stop=6 * G, step=1),
     "sample_rate": dev_range(start=1, stop=200 * M, step=1),
     "bandwidth": dev_range(start=1, stop=120 * M, step=1),
+    "subdevice": "",  # http://files.ettus.com/manual/page_configuration.html#config_subdev
     "rx_rf_gain": list(range(0, 101)),
     "tx_rf_gain": list(range(0, 101)),
-    "antenna": [0, 1]
+    "rx_antenna": ["Antenna 1", "Antenna 2", "Antenna 3"],
+    "tx_antenna": ["Antenna 1", "Antenna 2", "Antenna 3"]
 }
 
 # https://myriadrf.org/projects/limesdr/
@@ -74,7 +84,7 @@ DEVICE_CONFIG["RTL-SDR"] = {
     "center_freq": dev_range(start=0.1 * M, stop=2200 * M, step=1),
     "sample_rate": dev_range(start=1, stop=int(3.2 * M), step=1),
     "bandwidth": dev_range(start=1, stop=int(3.2 * M), step=1),
-    "rx_rf_gain": list(range(0, 51)),  # CAUTION: API is *10 so e.g. 1 needs to be given as 10 to API
+    "rx_rf_gain": list(range(-100, 500)),
     "direct_sampling": ["disabled", "I-ADC input enabled", "Q-ADC input enabled"],
     "freq_correction": dev_range(start=-1 * 10 ** 3, stop=1 * 10 ** 3, step=1)
 }
